# Django
from django.test import TestCase
from django.http import HttpResponseForbidden

# Mock
from mock import Mock

# Tasix
from tasix.middleware import TasixMiddleware


class TasixMiddlewareTest(TestCase):

    def setUp(self):
        self.middleware = TasixMiddleware()
        self.request = Mock()
        self.request.session = dict()

    def test_with_non_tasix_ip(self):
        self.request.META = dict()
        self.request.META['REMOTE_ADDR'] = '8.8.8.8'
        self.assertEquals(
            403,
            self.middleware.process_request(self.request).status_code)
        self.assertIsInstance(
            self.middleware.process_request(self.request),
            HttpResponseForbidden)

    def test_should_raise_keyerror_exception(self):
        self.request.META = dict()
        with self.assertRaises(KeyError):
            self.assertIsInstance(
                self.middleware.process_request(self.request),
                HttpResponseForbidden)

    def test_should_raise_typeerror_exception(self):
        with self.assertRaises(TypeError):
            self.assertIsInstance(
                self.middleware.process_request(self.request),
                HttpResponseForbidden)



# Copyright 2016 django-tasix authors. All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.

from django.conf import settings
from django.http import HttpResponseForbidden
from tasix.network import is_tasix_member


class TasixMiddleware(object):

    def process_request(self, request):
        ip_address = request.META['REMOTE_ADDR']
        allow_tasix = getattr(settings, "ALLOW_TASIX", True)
        if allow_tasix and not is_tasix_member(ip_address):
            return HttpResponseForbidden()



#!/usr/bin/env python

from setuptools import setup
import re
import os
import sys


def get_packages(package):
    return [dirpath
            for dirpath, dirnames, filenames in os.walk(package)
            if os.path.exists(os.path.join(dirpath, '__init__.py'))]


def get_package_data(package):
    walk = [(dirpath.replace(package + os.sep, '', 1), filenames)
            for dirpath, dirnames, filenames in os.walk(package)
            if not os.path.exists(os.path.join(dirpath, '__init__.py'))]

    filepaths = []
    for base, filenames in walk:
        filepaths.extend([os.path.join(base, filename)
                          for filename in filenames])
    return {package: filepaths}


setup(
    name='django-tasix',
    version='0.2.0',
    url='https://github.com/muminoff/django-tasix',
    license='MIT',
    description='Simple django app to allow/block IP addresses and ranges outside the Tas-IX network',
    long_description=open('Readme.md', 'r').read(),
    author='Sardor Muminov',
    author_email='smuminov@gmail.com',
    packages=get_packages('tasix'),
    package_data=get_package_data('.'),
    install_requires=[
        'netaddr',
    ],
    tests_require=['django'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
    ]
)
